@@ -25,7 +25,6 @@ from smartparams.cli import Print, parse_arguments
 from smartparams.io import load_data, print_data, save_data
 from smartparams.utils import (
     check_key_is_in,
-    check_key_is_in_bidict,
     check_missings,
     check_overrides,
     check_typings,
@@ -38,6 +37,7 @@ from smartparams.utils import (
     join_keys,
     parse_class,
     parse_param,
+    remove_duplicated_key_and_value,
     str_to_bool,
 )
 
@@ -247,6 +247,21 @@ class Smart(Generic[_T]):
         """
         return ((k, self.get(k)) for k in self.keys(flatten, pattern))
 
+    def isin(
+        self,
+        name: str,
+    ) -> bool:
+        """Checks if name is in dictionary.
+
+        Args:
+            name: The key to be checked.
+
+        Returns:
+            True if name is in dictionary, otherwise False.
+
+        """
+        return check_key_is_in(name, self._dict)
+
     def get(
         self,
         name: str,
@@ -324,29 +339,27 @@ class Smart(Generic[_T]):
         self,
         name: str,
         function: Callable,
-        default: Optional[Any] = ...,
     ) -> Any:
         """Applies value of given name to given function.
 
         Args:
             name: Name of value to be mapped.
             function: A function to which map passes a value.
-            default: Value returned if key doesn't exist.
 
         Returns:
             Mapped value.
 
         Raises:
-            ValueError if name doesn't exist and default value not specified.
+            ValueError if name doesn't exist.
 
         """
         dictionary, key = get_nested_dictionary_and_key(
             dictionary=self._dict,
             name=name,
-            required=default is ...,
+            required=True,
         )
 
-        dictionary[key] = value = function(dictionary[key]) if key in dictionary else default
+        dictionary[key] = value = function(dictionary[key])
         return value
 
     def update_from(
@@ -384,9 +397,8 @@ class Smart(Generic[_T]):
             raise TypeError(f"Source type '{type(source)}' is not supported.")
 
         if name is None:
-            _flatten_keys = tuple(self.keys(flatten=True))
             for key in smart.keys(flatten=True):
-                if override or not check_key_is_in(key, _flatten_keys):
+                if override or not self.isin(key):
                     self.set(key, smart.get(key))
         else:
             try:
@@ -751,7 +763,7 @@ class Smart(Generic[_T]):
             origin = origin if isinstance(origin, str) else inspect.formatannotation(origin)
             alias = join_keys(prefix, alias)
 
-            check_key_is_in_bidict(
+            remove_duplicated_key_and_value(
                 key=origin,
                 key_dict=self._aliases,
                 value_dict=self._origins,
@@ -759,7 +771,7 @@ class Smart(Generic[_T]):
                 raise_error=self.strict,
             )
 
-            check_key_is_in_bidict(
+            remove_duplicated_key_and_value(
                 key=alias,
                 key_dict=self._origins,
                 value_dict=self._aliases,
